The extremal index \(\theta\) is a measure of the degree of local dependence in the extremes of a stationary process. The exdex package performs frequentist inference about \(\theta\) using the methodologies proposed in Northrop (2015), Berghaus and Bucher (2018), Suveges (2007) and Suveges and Davison (2010).
Functions to implement three estimators of the extremal index are provided, namely
spm: semiparametric maxima estimator, using block
maxima: (Northrop, 2015; Berghaus and Bucher, 2018)
kgaps: \(K\)-gaps estimator, using threshold
interexceedance times (Suveges and Davison, 2010)
iwls: iterated weighted least squares estimator,
using threshold interexceedance times: (Suveges, 2007)
See vignette("exdex-vignette", package = "exdex") for an
overview of the package.
Berghaus, B., Bucher, A. (2018) Weak convergence of a pseudo maximum likelihood estimator for the extremal index. Ann. Statist. 46(5), 2307-2335. https://doi.org/10.1214/17-AOS1621
Northrop, P. J. (2015) An efficient semiparametric maxima estimator of the extremal index. Extremes 18(4), 585-603. https://doi.org/10.1007/s10687-015-0221-5
Suveges, M. (2007) Likelihood estimation of the extremal index. Extremes, 10, 41-55. https://doi.org/10.1007/s10687-007-0034-2
Suveges, M. and Davison, A. C. (2010) Model misspecification in peaks over threshold analysis, The Annals of Applied Statistics, 4(1), 203-221. https://doi.org/10.1214/09-AOAS292
spm for estimation of the extremal index
\(\theta\) using a semiparametric maxima method.
kgaps for maximum likelihood estimation of the
extremal index \(\theta\) using the \(K\)-gaps model.
iwls: iterated weighted least squares estimator.